==> diogenes_0.9.12.orig.tar.gz: diogenes-0.9.12/include/admin/ekit.php <==
<?php
require_once 'diogenes.common.inc.php';
require_once 'diogenes.admin.inc.php';
require_once 'diogenes.ekit.inc.php';

if (!isset($_REQUEST['dir']) && !isset($_REQUEST['file']))
  exit;

// retrieve directory & file info
$dir = $_REQUEST["dir"];
$file = $_REQUEST["file"];
$page = new DiogenesAdmin($dir);

$res = $globals->db->query("select location from {$page->table_page} where PID='$dir'");
if (!list($dirloc) = mysql_fetch_row($res))
  $page->kill(__("Directory not found"));

// rcs handle
$rcs = $page->getRcs();

// file location & url
$mydir = $page->spool->spoolPath($dir);
$myfile = $page->spool->spoolPath($dir,$file);

// process requested action
$action = isset($_REQUEST["action"]) ? $_REQUEST["action"] : "";
switch ($action)
{
case "update":
  // update the current file with form contents
  if (isset($_REQUEST['file_content'])) {
    $page->info(__("Commiting changes to file") . " $file");
    $content = trim($_REQUEST['file_content']);
    $content = str_replace("\n    ","\n",$content);
    $content = phpUnprotect(htmltoXhtml($content));
    $message = empty($_REQUEST['message']) ? "updated using ekit" : stripslashes($_REQUEST['message']);
    $rcs->commit($dir,$file,stripslashes($content),$message);
  }

  break;
}

$rev = array_shift($rcs->logParse($dir,$file));

// protect PHP code and XHTML tags
$rawdoc = file_get_contents($myfile);
$protdoc = xhtmlToHtml(phpProtect($rawdoc));

// smarty assignments
$page->assign('greeting', __("Ekit")." - $dirloc/$file - {$rev['rev']}");
$page->assign('post',$page->script_self());
$page->assign('dir',$dir);
$page->assign('dirloc',$page->urlSite($dirloc ? "$dirloc/" : ""));
$page->assign('file',$file);
$page->assign('file_content',chunk_split(base64_encode($protdoc)));
$page->assign('msg_log',__("log message"));
$page->toolbar(__("Page"), array (
  array( __("pages catalog"), "pages"),
  array( __("page properties"), "pages?PID=$dir" ),
  array( __("view page"), $page->urlSite($dirloc ? "$dirloc/" : "")),
  array( __("browse files"), "files?dir=$dir" )
));
$page->toolbar(__("File"), array (
  array( __("raw editor"), "edit?dir=$dir&amp;file=$file" ),
  array( __("HTML editor") ),
  array( __("file revisions"), "files?action=revs&amp;dir=$dir&amp;target=$file" )
));
$page->display('admin-ekit.tpl');
?>

==> diogenes_0.9.14.orig.tar.gz: diogenes-0.9.14/include/admin/ekit.php <==
<?php
require_once 'diogenes.common.inc.php';
require_once 'diogenes.admin.inc.php';
require_once 'diogenes.ekit.inc.php';

if (!isset($_REQUEST['dir']) && !isset($_REQUEST['file']))
  exit;

// retrieve directory & file info
$dir = $_REQUEST["dir"];
$file = $_REQUEST["file"];
$page = new DiogenesAdmin($dir);

$res = $globals->db->query("select location from {$page->table_page} where PID='$dir'");
if (!list($dirloc) = mysql_fetch_row($res))
  $page->kill(__("Directory not found"));

// rcs handle
$rcs = $page->getRcs();

// file location & url
$mydir = $page->spool->spoolPath($dir);
$myfile = $page->spool->spoolPath($dir,$file);

// process requested action
$action = isset($_REQUEST["action"]) ? $_REQUEST["action"] : "";
switch ($action)
{
case "update":
  // update the current file with form contents
  if (isset($_REQUEST['file_content'])) {
    $page->info(__("Commiting changes to file") . " $file");
    $content = trim($_REQUEST['file_content']);
    $content = str_replace("\n    ","\n",$content);
    $content = phpUnprotect(htmltoXhtml($content));
    $message = empty($_REQUEST['message']) ? "updated using ekit" : stripslashes($_REQUEST['message']);
    $rcs->commit($dir,$file,stripslashes($content),$message);
  }

  break;
}

$rev = array_shift($rcs->logParse($dir,$file));

// protect PHP code and XHTML tags
$rawdoc = file_get_contents($myfile);
$protdoc = xhtmlToHtml(phpProtect($rawdoc));

// smarty assignments
$page->assign('greeting', __("Ekit")." - $dirloc/$file - {$rev['rev']}");
$page->assign('post',$page->script_self());
$page->assign('dir',$dir);
$page->assign('dirloc',$page->urlBarrel($page->alias,$page->vhost,$dirloc ? "$dirloc/" : ""));
$page->assign('ekitcss',$page->urlSite($globals->cssfile));
$page->assign('file',$file);
$page->assign('file_content',chunk_split(base64_encode($protdoc)));
$page->assign('msg_log',__("log message"));
$page->toolbar(__("Page"), array (
  array( __("pages catalog"), "pages"),
  array( __("page properties"), "pages?PID=$dir" ),
  array( __("view page"), $page->urlSite($dirloc ? "$dirloc/" : "")),
  array( __("browse files"), "files?dir=$dir" )
));
$page->toolbar(__("File"), array (
  array( __("raw editor"), "edit?dir=$dir&amp;file=$file" ),
  array( __("HTML editor") ),
  array( __("file revisions"), "files?action=revs&amp;dir=$dir&amp;target=$file" )
));
$page->display('admin-ekit.tpl');
?>
